@@ -171,8 +171,8 @@ def unpublish(
     process_response(r)
 
 
-@app.command(name="schema")
-def get_schema(
+@app.command(name="get")
+def get_product(
     ctx: typer.Context,
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
 ):
@@ -182,7 +182,7 @@ def get_schema(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            "{dp_url}/{name}/schema".format(dp_url=product_url(ctx), name=product_name),
+            "{dp_url}/{name}".format(dp_url=product_url(ctx), name=product_name),
         )
 
     r = _request(ctx)
@@ -202,7 +202,7 @@ def preview(
     def _request(ctx: typer.Context) -> httpx.Response:
         return util.get(
             ctx,
-            "{product_url}/{name}".format(
+            "{product_url}/{name}/data".format(
                 product_url=product_url(ctx),
                 name=product_name,
             ),
