@@ -167,6 +167,11 @@ def csv_job(
     product_name: str = typer.Argument(os.getenv("NEOSCTL_PRODUCT", ...), help="Data Product name"),
     delimiter: str = typer.Option(",", "--delimiter", "-d", help="csv delimiter"),
     quotechar: typing.Optional[str] = typer.Option(None, "--quote-char", "-q", help="csv quote char"),
+    csv_write_mode: typing.Optional[str] = typer.Option(
+        None,
+        "--write-mode", "-w",
+        help="csv write mode [overwrite|append]",
+    ),
     job_filepath: str = typer.Option(..., "--job-filepath", "-f"),
 ):
     """Ingest a csv file into a data product.
@@ -176,12 +181,15 @@ def csv_job(
     @ensure_login
     def _request(ctx: typer.Context, f: typing.IO) -> httpx.Response:
         params = {
-            "delimiter": delimiter,
+            k: v
+            for k, v in [
+                ("delimiter", delimiter),
+                ("quotechar", quotechar),
+                ("csv_write_mode", csv_write_mode),
+            ]
+            if v is not None
         }
 
-        if quotechar is not None:
-            params["quotechar"] = quotechar
-
         return util.post(
             ctx,
             "{spark_url}/csv".format(spark_url=spark_url(product_name, ctx.obj.gateway_api_url)),
